@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -293,5 +293,11 @@ __all__ = [
     'SiameseDataGenerator',
     'SiameseIterator',
     'CroppingDataGenerator',
-    'CroppingIterator'
+    'CroppingIterator',
+    'SemanticIterator',
+    'SemanticDataGenerator',
+    'SemanticMovieIterator',
+    'SemanticMovieGenerator',
+    'Semantic3DIterator',
+    'Semantic3DGenerator',
 ]
